# EnvironmentConfigVar

A unique name that refers to a specific env_config.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name of an environment variable. It must be a C_IDENTIFIER. An Identifier can only have alphanumeric characters(a-z , A-Z , 0-9) and underscore( _ ). It is also case-sensitive.  | 
**value** | **str** | The value of the environment variable to be passed to the running application&#39;s environment.  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


